# TODO: Multi panel plot
# 
# Author: pv1
###############################################################################

`MultiPanelPlot` <- function(allX,allXscore,Fd_rep,sample_id,known_rstr="", gene_file,misc_str="",mother_id="",father_id="") {
		
	chr = Fd_rep[,1]; gene_start = Fd_rep[,2]; gene_end = Fd_rep[,3]; no_of_exons <- Fd_rep[,4]; score = round(Fd_rep[,5], digits=2)
	diff = gene_end-gene_start; cnv = as.character(Fd_rep$cnv_type)
	lgnd1 <- paste(gene_start,"-",gene_end," (",(diff+1),"bp) / ",no_of_exons," probe regions / CoNVex score = ",score,sep="") # Legend
	plotfile = paste("CoNVexMultiPanel_",cnv,"_",sample_id,"_Chr",chr,"-",gene_start,"-",gene_end,".png",sep="")
	
	if(cnv=="DUP") {
		ptitl <- paste("CoNVex duplication call: Chr",chr,"in Sample",sample_id)
		colour = "blue";
	} else {
		ptitl <- paste("CoNVex deletion call: Chr",chr,"in Sample",sample_id)
		colour = "red";
	}
	
	all100 <- allX[as.character(allX[,2])==as.character(chr) & (allX[,3]>(gene_start-diff)) & (allX[,4]<(gene_end+diff)),];
	all100call <- allX[as.character(allX[,2])==as.character(chr) & (allX[,3]>=gene_start) & (allX[,4]<=gene_end),]; 
	
	if(length(all100[,1])==1) { # only one row
		rowtmp <- which(allX[,1]==all100[,1])
		if(rowtmp <= 5) {
			rowtmps <- 1
		} else {
			rowtmps <- rowtmp-5
		}
		all100 <- allX[rowtmps:(rowtmp+5),]
		all100 <- all100[as.character(all100[,2])==as.character(chr),]					
	}
	if(length(all100[,1])<=5) { # Centre point is set at the 2nd row
		rowtmp <- which(allX[,1]==all100[2,1])
		if(rowtmp <= 5) {
			rowtmps <- 1
		} else {
			rowtmps <- rowtmp-5
		}
		all100 <- allX[rowtmps:(rowtmp+5),]
		all100 <- all100[as.character(all100[,2])==as.character(chr),]			
	}
	all100score <- allXscore[allXscore[,1] %in% all100[,1],]
	
	png(file=plotfile, width=960, height=960)
	colmat = rbind(c(1:4),c(552,26,525,403),c(9,8,7,6)) # colour matrix: Rows 1,2,3: cnvtype, colour, y-location in plot
	mat = matrix(c(1,2,3), nrow=3,ncol=1) # Multipanel stuff
	par(mar = c(0,4,2,1))
	layout(mat, heights=c(1/3,1/3,1/3))
	
	nm1 = all100[,c(3,5:length(all100))]; nm2 = all100[,4:length(all100)]; names(nm1)[1] = "chrpos"; names(nm2)[1] = "chrpos"; nm = rbind(nm1,nm2); nm = nm[with(nm,order(nm[,1])),];
	cnvrange = c(min(all100call[,3]), max(all100call[,4])); 
	if(length(which(nm[,1] < cnvrange[1]))==0) {cnvmaxrange1 = cnvrange[1]; } else {cnvmaxrange1 = max(nm[nm[,1] < cnvrange[1],1])}
	if(length(which(nm[,1] > cnvrange[2]))==0) {cnvmaxrange2 = cnvrange[2]; } else {cnvmaxrange2 = min(nm[nm[,1] > cnvrange[2],1])}
	cnvmaxrange =  c(cnvmaxrange1,cnvmaxrange2);
	
	matplot(nm[,1], nm[,5:length(nm)], type="l", lty=1, xlab="", ylab="log2ratio", main=ptitl, col=8, xaxt="n",cex.axis=1.5,cex.lab=1.5,cex.main=1.8)
	sid = which(names(nm) == sample_id)
	
	if(mother_id != "") { sid = c(sid,which(names(nm) == mother_id)); colour = c(colour,colors()[547]); }
	if(father_id != "") { sid = c(sid,which(names(nm) == father_id)); colour = c(colour,"green"); }
	for(si in 1:length(sid)) { lines(nm[,1], nm[,sid[si]], lty=1,col=colour[si]); }
	
	if(cnv=="DUP") {
		legend("bottomleft",legend=lgnd1, text.col="darkviolet",cex=1.5)
	} else {
		legend("topleft",legend=lgnd1, text.col="darkviolet",cex=1.5)
	}
	abline(v=cnvrange, col=9, lty=3)
	abline(v=cnvmaxrange, col=9, lty=2)
	
	nm1 = all100score[,c(3,5:length(all100score))]; nm2 = all100score[,4:length(all100score)]; names(nm1)[1] = "chrpos"; names(nm2)[1] = "chrpos"; nm = rbind(nm1,nm2); nm = nm[with(nm,order(nm[,1])),];
	
	par(mar = c(0,4,1,1))
	matplot(nm[,1], nm[,5:length(nm)], type="l", lty=1, xlab="", ylab="ADM3 scores", col=8, xaxt="n",cex.axis=1.5,cex.lab=1.5,cex.main=1.8)
	
	for(si in 1:length(sid)) { lines(nm[,1], nm[,sid[si]], lty=1,col=colour[si]); }
	abline(v=cnvrange, col=9, lty=3)
	abline(v=cnvmaxrange, col=9, lty=2)
	
	# Genes + Transcripts
	#Allfeat_Genes = read.table(gene_file); Allfeat_Genes = data.frame(seq(1,nrow(Allfeat_Genes)),Allfeat_Genes);
	GT = gene_file[gene_file[,1] %in% all100call[,1],5:6]
	######genes = paste("Genes:",getGeneSymbols(GT))
	genes = getGeneSymbols(GT);
	
	par(mar = c(4,4,1,1))
	lv = sample(0:10,length(nm[,1]), replace=TRUE); lv[1] = 0; lv[2] = 10;
	plot(nm[,1],lv, xlab="Chr position", ylab="", yaxt="n",col="#FFFFFF", cex.axis=1.5,cex.lab=1.5)
	abline(v=cnvrange, col=9, lty=3)
	abline(v=cnvmaxrange, col=9, lty=2)
	gx = cnvrange[1]; gy = min(colmat[3,])-1;
	text(x=gx, y=gy, labels=genes, col=colors()[556], pos=4, cex=1.3)
	
	if(known_rstr != "") {
		for(cm in colmat[1,]) {
			
			cnve = known_rstr[known_rstr[,3]==cm,]; ccol = colors()[colmat[2,cm]]; yloc = colmat[3,cm]; 
			if(cnve[1,1]!=0) { 
				for(jj in 1:nrow(cnve)) {
					ks = c(cnve[jj,1]:cnve[jj,2])
					lines(x=ks, y=rep(colmat[3,cm],length(ks)), col=ccol,lwd=2)		
				}
			}
		}
	}
	legend("bottomright",legend=c(misc_str,paste("Mother",mother_id),paste("Father",father_id),"Known_Dels","Known_Dups"), box.lty=0, lty = 1, col = colors()[c(3,547,254,colmat[2,1:2])], lwd=2, cex=1.3)
	
	dev.off()
}

